@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "springgraphics.h"
@@ -61,14 +49,14 @@ void SpringHandlerGraphicsItem::mouseSetPos(const QPointF& pos, const QPointF&,
 {
     static_cast<WorldScene*>(scene())->snapItem(parentItem()->mapToParent(pos),
                     WorldScene::SnapParticle | WorldScene::SnapRigidBody |
-                    WorldScene::SnapSetLocalPosition, 0, movingState, _item, _num);
+                    WorldScene::SnapSetLocalPosition, nullptr, movingState, _item, _num);
 
 }
 
 SpringGraphicsItem::SpringGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : StepGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Spring*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Spring*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setZValue(FORCE_ZVALUE);
@@ -171,7 +159,7 @@ void SpringGraphicsItem::viewScaleChanged()
 
     double u = 1/s;
     _painterPath.addRect(QRectF(-u, -_radius-u, _rnorm+u, _radius*2+u));
-    _painterPath = QMatrix().rotate(atan2(r[1], r[0])*180/3.14).map(_painterPath);
+    _painterPath = QTransform().rotate(atan2(r[1], r[0])*180/3.14).map(_painterPath);
         
     //update(); // XXX: documentation says this is unnecessary, but it doesn't work without it
 }
@@ -207,7 +195,7 @@ void SpringGraphicsItem::mouseSetPos(const QPointF& /*pos*/, const QPointF& diff
         Q_ASSERT(spring()->body1()->metaObject()->inherits<StepCore::Item>());
         StepGraphicsItem* gItem = static_cast<WorldScene*>(
             scene())->graphicsFromItem(static_cast<StepCore::Item*>(spring()->body1()));
-        Q_ASSERT(gItem != NULL);
+        Q_ASSERT(gItem != nullptr);
         if(!gItem->isSelected()) {
             _worldModel->setProperty(_item, QStringLiteral("localPosition1"),
                         _item->metaObject()->property(QStringLiteral("position1"))->readVariant(_item));
@@ -223,7 +211,7 @@ void SpringGraphicsItem::mouseSetPos(const QPointF& /*pos*/, const QPointF& diff
         Q_ASSERT(spring()->body2()->metaObject()->inherits<StepCore::Item>());
         StepGraphicsItem* gItem = static_cast<WorldScene*>(
             scene())->graphicsFromItem(static_cast<StepCore::Item*>(spring()->body2()));
-        Q_ASSERT(gItem != NULL);
+        Q_ASSERT(gItem != nullptr);
         if(!gItem->isSelected()) {
             _worldModel->setProperty(_item, QStringLiteral("localPosition2"),
                         _item->metaObject()->property(QStringLiteral("position2"))->readVariant(_item));
