@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "worldfactory.h"
@@ -218,7 +206,7 @@ ItemCreator* WorldFactory::newItemCreator(const QString& className,
                     WorldModel* worldModel, WorldScene* worldScene) const
 {
     const StepCore::MetaObject* mObject = metaObject(className);
-    if(!mObject) return NULL;
+    if(!mObject) return nullptr;
     const ExtMetaObject *extMetaObject = _extMetaObjects.value(mObject, NULL);
     if(extMetaObject && extMetaObject->newItemCreator)
         return extMetaObject->newItemCreator(className, worldModel, worldScene);
@@ -230,7 +218,7 @@ StepGraphicsItem* WorldFactory::newGraphicsItem(StepCore::Item* item, WorldModel
     const ExtMetaObject *extMetaObject = _extMetaObjects.value(item->metaObject(), NULL);
     if(extMetaObject && extMetaObject->newGraphicsItem)
         return extMetaObject->newGraphicsItem(item, worldModel);
-    return NULL;
+    return nullptr;
 }
 
 ItemMenuHandler* WorldFactory::newItemMenuHandler(StepCore::Object* object, WorldModel* worldModel, QObject* parent) const
