@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STEP_WORLDGRAPHICS_H
@@ -45,7 +33,7 @@ class ItemCreator
 public:
     ItemCreator(const QString& className, WorldModel* worldModel, WorldScene* worldScene)
            : _className(className), _worldModel(worldModel),
-             _worldScene(worldScene), _item(NULL), _finished(false), _messageId(-1) {}
+             _worldScene(worldScene), _item(nullptr), _finished(false), _messageId(-1) {}
     virtual ~ItemCreator() { closeMessage(); }
 
     /** Returns class name of the item which this creator creates */
@@ -111,7 +99,7 @@ public:
     AttachableItemCreator(const QString& className, WorldModel* worldModel, WorldScene* worldScene)
                 : ItemCreator(className, worldModel, worldScene),
                     _snapFlags(WorldScene::SnapParticle | WorldScene::SnapRigidBody |
-                    WorldScene::SnapSetPosition | WorldScene::SnapSetLocalPosition), _snapTypes(0), _twoEnds(false) {}
+                    WorldScene::SnapSetPosition | WorldScene::SnapSetLocalPosition), _snapTypes(nullptr), _twoEnds(false) {}
 
     /** Constructs AttachableItemCreator
      *
@@ -149,7 +137,7 @@ class ItemMenuHandler : public QObject
     Q_OBJECT
 
 public:
-    ItemMenuHandler(StepCore::Object* object, WorldModel* worldModel, QObject* parent = 0);
+    ItemMenuHandler(StepCore::Object* object, WorldModel* worldModel, QObject* parent = nullptr);
 
     /** Populate context menu by item-specific entries.
      *  Default implementation adds delete action. */
