@@ -1,19 +1,7 @@
-/* This file is part of StepCore library.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   StepCore library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   StepCore library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with StepCore; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "joints.h"
@@ -64,18 +52,18 @@ void Anchor::setBody(Object* body)
         if(body->metaObject()->inherits<Particle>()) {
             _body = body;
             _p = static_cast<Particle*>(body);
-            _r = NULL;
+            _r = nullptr;
             return;
         } else if(body->metaObject()->inherits<RigidBody>()) {
             _body = body;
-            _p = NULL;
+            _p = nullptr;
             _r = static_cast<RigidBody*>(body);
             return;
         }
     }
-    _body = NULL;
-    _p = NULL;
-    _r = NULL;
+    _body = nullptr;
+    _p = nullptr;
+    _r = nullptr;
 }
 
 int Anchor::constraintsCount()
@@ -125,18 +113,18 @@ void Pin::setBody(Object* body)
         if(body->metaObject()->inherits<Particle>()) {
             _body = body;
             _p = static_cast<Particle*>(body);
-            _r = NULL;
+            _r = nullptr;
             return;
         } else if(body->metaObject()->inherits<RigidBody>()) {
             _body = body;
-            _p = NULL;
+            _p = nullptr;
             _r = static_cast<RigidBody*>(body);
             return;
         }
     }
-    _body = NULL;
-    _p = NULL;
-    _r = NULL;
+    _body = nullptr;
+    _p = nullptr;
+    _r = nullptr;
 }
 
 int Pin::constraintsCount()
@@ -210,18 +198,18 @@ void Stick::setBody1(Object* body1)
         if(body1->metaObject()->inherits<Particle>()) {
             _body1 = body1;
             _p1 = static_cast<Particle*>(body1);
-            _r1 = NULL;
+            _r1 = nullptr;
             return;
         } else if(body1->metaObject()->inherits<RigidBody>()) {
             _body1 = body1;
-            _p1 = NULL;
+            _p1 = nullptr;
             _r1 = static_cast<RigidBody*>(body1);
             return;
         }
     }
-    _body1 = NULL;
-    _p1 = NULL;
-    _r1 = NULL;
+    _body1 = nullptr;
+    _p1 = nullptr;
+    _r1 = nullptr;
 }
 
 void Stick::setBody2(Object* body2)
@@ -230,18 +218,18 @@ void Stick::setBody2(Object* body2)
         if(body2->metaObject()->inherits<Particle>()) {
             _body2 = body2;
             _p2 = static_cast<Particle*>(body2);
-            _r2 = NULL;
+            _r2 = nullptr;
             return;
         } else if(body2->metaObject()->inherits<RigidBody>()) {
             _body2 = body2;
-            _p2 = NULL;
+            _p2 = nullptr;
             _r2 = static_cast<RigidBody*>(body2);
             return;
         }
     }
-    _body2 = NULL;
-    _p2 = NULL;
-    _r2 = NULL;
+    _body2 = nullptr;
+    _p2 = nullptr;
+    _r2 = nullptr;
 }
 
 Vector2d Stick::position1() const
